resource_groups = {
    "fastly_service_v1": 0,
    "consul_agent_service": 1,
    "consul_catalog_entry": 1,
    "consul_keys": 1,
    "consul_key_prefix": 1,
    "consul_node": 1,
    "consul_prepared_query": 1,
    "consul_service": 1,
    "postgresql_database": 2,
    "postgresql_extension": 2,
    "postgresql_role": 2,
    "postgresql_schema": 2,
    "heroku_addon": 3,
    "heroku_addon_attachment": 3,
    "heroku_app": 3,
    "heroku_app_feature": 3,
    "heroku_cert": 3,
    "heroku_domain": 3,
    "heroku_drain": 3,
    "heroku_pipeline": 3,
    "heroku_pipeline_coupling": 3,
    "heroku_space": 3,
    "bitbucket_default_reviewers": 4,
    "bitbucket_hook": 4,
    "bitbucket_repository": 4,
    "azurerm_resource_group": 5,
    "azurerm_app_service": 6,
    "azurerm_app_service_plan": 6,
    "azurerm_function_app": 6,
    "azurerm_role_assignment": 7,
    "azurerm_role_definition": 7,
    "azurerm_automation_account": 8,
    "azurerm_automation_credential": 8,
    "azurerm_automation_runbook": 8,
    "azurerm_automation_schedule": 8,
    "azurerm_application_insights": 9,
    "azurerm_cdn_profile": 10,
    "azurerm_cdn_endpoint": 10,
    "azurerm_availability_set": 11,
    "azurerm_managed_disk": 11,
    "azurerm_snapshot": 11,
    "azurerm_image": 11,
    "azurerm_virtual_machine": 11,
    "azurerm_virtual_machine_extension": 11,
    "azurerm_virtual_machine_scale_set": 11,
    "azurerm_container_group": 12,
    "azurerm_container_registry": 12,
    "azurerm_container_service": 12,
    "azurerm_cosmosdb_account": 13,
    "azurerm_mysql_configuration": 14,
    "azurerm_mysql_database": 14,
    "azurerm_mysql_firewall_rule": 14,
    "azurerm_mysql_server": 14,
    "azurerm_postgresql_configuration": 14,
    "azurerm_postgresql_database": 14,
    "azurerm_postgresql_firewall_rule": 14,
    "azurerm_postgresql_server": 14,
    "azurerm_sql_database": 14,
    "azurerm_sql_elasticpool": 14,
    "azurerm_sql_firewall_rule": 14,
    "azurerm_sql_server": 14,
    "azurerm_dns_a_record": 15,
    "azurerm_dns_aaaa_record": 15,
    "azurerm_dns_cname_record": 15,
    "azurerm_dns_mx_record": 15,
    "azurerm_dns_ns_record": 15,
    "azurerm_dns_ptr_record": 15,
    "azurerm_dns_srv_record": 15,
    "azurerm_dns_txt_record": 15,
    "azurerm_dns_zone": 15,
    "azurerm_key_vault": 16,
    "azurerm_key_vault_certificate": 16,
    "azurerm_key_vault_key": 16,
    "azurerm_key_vault_secret": 16,
    "azurerm_lb": 17,
    "azurerm_lb_backend_address_pool": 17,
    "azurerm_lb_rule": 17,
    "azurerm_lb_nat_rule": 17,
    "azurerm_lb_nat_pool": 17,
    "azurerm_lb_probe": 17,
    "azurerm_management_lock": 18,
    "azurerm_eventgrid_topic": 19,
    "azurerm_eventhub": 19,
    "azurerm_eventhub_authorization_rule": 19,
    "azurerm_eventhub_consumer_group": 19,
    "azurerm_eventhub_namespace": 19,
    "azurerm_servicebus_namespace": 19,
    "azurerm_servicebus_queue": 19,
    "azurerm_servicebus_subscription": 19,
    "azurerm_servicebus_topic": 19,
    "azurerm_application_gateway": 20,
    "azurerm_express_route_circuit": 20,
    "azurerm_local_network_gateway": 20,
    "azurerm_network_interface": 20,
    "azurerm_network_security_group": 20,
    "azurerm_network_security_rule": 20,
    "azurerm_network_watcher": 20,
    "azurerm_public_ip": 20,
    "azurerm_route": 20,
    "azurerm_route_table": 20,
    "azurerm_subnet": 20,
    "azurerm_traffic_manager_endpoint": 20,
    "azurerm_traffic_manager_profile": 20,
    "azurerm_virtual_network": 20,
    "azurerm_virtual_network_peering": 20,
    "azurerm_log_analytics_workspace": 21,
    "azurerm_redis_cache": 22,
    "azurerm_redis_firewall_rule": 22,
    "azurerm_search_service": 23,
    "azurerm_storage_account": 24,
    "azurerm_storage_container": 24,
    "azurerm_storage_blob": 24,
    "azurerm_storage_queue": 24,
    "azurerm_storage_share": 24,
    "azurerm_storage_table": 24,
    "azurerm_template_deployment": 25,
    "clc_server": 26,
    "clc_group": 26,
    "clc_public_ip": 26,
    "clc_load_balancer": 26,
    "clc_load_balancer_pool": 26,
    "cloudflare_record": 27,
    "aws_group": 28,
    "vault_auth_backend": 29,
    "vault_aws_auth_backend_cert": 29,
    "vault_aws_auth_backend_client": 29,
    "vault_aws_auth_backend_login": 29,
    "vault_aws_auth_backend_role": 29,
    "vault_aws_auth_backend_sts_role": 29,
    "vault_aws_secret_backend": 29,
    "vault_aws_secret_backend_role": 29,
    "vault_generic_secret": 29,
    "vault_mount": 29,
    "vault_policy": 29,
    "newrelic_alert_channel": 30,
    "newrelic_alert_condition": 30,
    "newrelic_alert_policy": 30,
    "newrelic_alert_policy_channel": 30,
    "newrelic_nrql_alert_condition": 30,
    "github_branch_protection": 31,
    "github_membership": 31,
    "github_organization_webhook": 31,
    "github_repository": 31,
    "github_repository_collaborator": 31,
    "github_repository_deploy_key": 31,
    "github_repository_webhook": 31,
    "github_team": 31,
    "github_team_membership": 31,
    "github_team_repository": 31,
    "github_issue_label": 31,
    "scaleway_ip": 32,
    "scaleway_server": 32,
    "scaleway_security_group": 32,
    "scaleway_security_group_rule": 32,
    "scaleway_volume": 32,
    "scaleway_volume_attachment": 32,
    "dme_record": 33,
    "mysql_database": 34,
    "mysql_grant": 34,
    "mysql_user": 34,
    "rancher_certificate": 35,
    "rancher_environment": 35,
    "rancher_host": 35,
    "rancher_registration_token": 35,
    "rancher_registry_credential": 35,
    "rancher_registry": 35,
    "rancher_secret": 35,
    "rancher_stack": 35,
    "rancher_volume": 35,
    "opsgenie_team": 36,
    "opsgenie_user": 36,
    "chef_data_bag": 37,
    "chef_data_bag_item": 37,
    "chef_environment": 37,
    "chef_node": 37,
    "chef_role": 37,
    "circonus_check": 38,
    "circonus_contact_group": 38,
    "circonus_graph": 38,
    "circonus_metric": 38,
    "circonus_metric_cluster": 38,
    "circonus_rule_set": 38,
    "cobbler_distro": 39,
    "cobbler_kickstart_file": 39,
    "cobbler_repo": 39,
    "cobbler_profile": 39,
    "cobbler_snippet": 39,
    "cobbler_system": 39,
    "cloudscale_server": 40,
    "cloudscale_floating_ip": 40,
    "virtual_guest": 41,
    "ssh_key": 41,
    "librato_alert": 42,
    "librato_metric": 42,
    "librato_service": 42,
    "librato_space": 42,
    "librato_space_chart": 42,
    "vsphere_license": 43,
    "vsphere_custom_attribute": 44,
    "vsphere_datacenter": 44,
    "vsphere_folder": 44,
    "vsphere_tag": 44,
    "vsphere_tag_category": 44,
    "vsphere_distributed_port_group": 45,
    "vsphere_distributed_virtual_switch": 45,
    "vsphere_host_port_group": 45,
    "vsphere_host_virtual_switch": 45,
    "vsphere_file": 46,
    "vsphere_nas_datastore": 46,
    "vsphere_vmfs_datastore": 46,
    "vsphere_virtual_disk": 47,
    "vsphere_virtual_machine": 47,
    "vsphere_virtual_machine_snapshot": 47,
    "mailgun_domain": 48,
    "google_bigquery_dataset": 50,
    "google_bigquery_table": 50,
    "google_bigtable_instance": 51,
    "google_bigtable_table": 51,
    "google_folder": 52,
    "google_folder_iam_policy": 52,
    "google_folder_organization_policy": 52,
    "google_organization_policy": 52,
    "google_organization_iam_binding": 52,
    "google_organization_iam_custom_role": 52,
    "google_organization_iam_member": 52,
    "google_project": 52,
    "google_project_iam_binding": 52,
    "google_project_iam_member": 52,
    "google_project_iam_policy": 52,
    "google_project_iam_custom_role": 52,
    "google_project_service": 52,
    "google_project_services": 52,
    "google_service_account": 52,
    "google_service_account_key": 52,
    "google_compute_address": 53,
    "google_compute_autoscaler": 53,
    "google_compute_backend_bucket": 53,
    "google_compute_backend_service": 53,
    "google_compute_disk": 53,
    "google_compute_firewall": 53,
    "google_compute_forwarding_rule": 53,
    "google_compute_global_address": 53,
    "google_compute_global_forwarding_rule": 53,
    "google_compute_health_check": 53,
    "google_compute_http_health_check": 53,
    "google_compute_https_health_check": 53,
    "google_compute_image": 53,
    "google_compute_instance": 53,
    "google_compute_instance_group": 53,
    "google_compute_instance_group_manager": 53,
    "google_compute_instance_template": 53,
    "google_compute_network_peering": 53,
    "google_compute_network": 53,
    "google_compute_project_metadata": 53,
    "google_compute_project_metadata_item": 53,
    "google_compute_region_autoscaler": 53,
    "google_compute_region_backend_service": 53,
    "google_compute_region_instance_group_manager": 53,
    "google_compute_route": 53,
    "google_compute_router": 53,
    "google_compute_router_interface": 53,
    "google_compute_router_peer": 53,
    "google_compute_shared_vpc_host_project": 53,
    "google_compute_shared_vpc_service_project": 53,
    "google_compute_snapshot": 53,
    "google_compute_ssl_certificate": 53,
    "google_compute_subnetwork": 53,
    "google_compute_target_http_proxy": 53,
    "google_compute_target_https_proxy": 53,
    "google_compute_target_ssl_proxy": 53,
    "google_compute_target_tcp_proxy": 53,
    "google_compute_target_pool": 53,
    "google_compute_url_map": 53,
    "google_compute_vpn_gateway": 53,
    "google_compute_vpn_tunnel": 53,
    "google_container_cluster": 54,
    "google_container_node_pool": 54,
    "google_dataproc_cluster": 55,
    "google_dns_managed_zone": 56,
    "google_dns_record_set": 56,
    "google_pubsub_topic": 57,
    "google_pubsub_subscription": 57,
    "google_runtimeconfig_config": 58,
    "google_runtimeconfig_variable": 58,
    "google_sourcerepo_repository": 59,
    "google_spanner_instance": 60,
    "google_spanner_database": 60,
    "google_sql_database": 61,
    "google_sql_database_instance": 61,
    "google_sql_user": 61,
    "google_logging_billing_account_sink": 62,
    "google_logging_folder_sink": 62,
    "google_logging_project_sink": 62,
    "google_storage_bucket": 63,
    "google_storage_bucket_acl": 63,
    "google_storage_bucket_iam_binding": 63,
    "google_storage_bucket_iam_member": 63,
    "google_storage_bucket_object": 63,
    "google_storage_object_acl": 63,
    "google_kms_key_ring": 64,
    "google_kms_key_ring_iam_binding": 64,
    "google_kms_key_ring_iam_member": 64,
    "google_kms_key_ring_iam_policy": 64,
    "google_kms_crypto_key": 64,
    "google_kms_crypto_key_iam_binding": 64,
    "google_kms_crypto_key_iam_member": 64,
    "packet_device": 65,
    "packet_project": 65,
    "packet_ssh_key": 65,
    "packet_volume": 65,
    "packet_volume_attachment": 65,
    "oneandone_firewall_policy": 66,
    "oneandone_loadbalancer": 66,
    "oneandone_monitoring_policy": 66,
    "oneandone_private_network": 66,
    "oneandone_public_ip": 66,
    "oneandone_server": 66,
    "oneandone_shared_storage": 66,
    "oneandone_vpn": 66,
    "kubernetes_config_map": 67,
    "kubernetes_horizontal_pod_autoscaler": 67,
    "kubernetes_limit_range": 67,
    "kubernetes_namespace": 67,
    "kubernetes_persistent_volume": 67,
    "kubernetes_persistent_volume_claim": 67,
    "kubernetes_pod": 67,
    "kubernetes_replication_controller": 67,
    "kubernetes_resource_quota": 67,
    "kubernetes_secret": 67,
    "kubernetes_service": 67,
    "kubernetes_service_account": 67,
    "kubernetes_storage_class": 67,
    "profitbricks_datacenter": 68,
    "profitbricks_firewall": 68,
    "profitbricks_group": 68,
    "profitbricks_ipblock": 68,
    "profitbricks_ipfailover": 68,
    "profitbricks_lan": 68,
    "profitbricks_loadbalancer": 68,
    "profitbricks_nic": 68,
    "profitbricks_server": 68,
    "profitbricks_share": 68,
    "profitbricks_snapshot": 68,
    "profitbricks_user": 68,
    "profitbricks_volume": 68,
    "template_dir": 69,
    "aws_api_gateway_account": 70,
    "aws_api_gateway_api_key": 70,
    "aws_api_gateway_authorizer": 70,
    "aws_api_gateway_base_path_mapping": 70,
    "aws_api_gateway_client_certificate": 70,
    "aws_api_gateway_deployment": 70,
    "aws_api_gateway_documentation_part": 70,
    "aws_api_gateway_domain_name": 70,
    "aws_api_gateway_gateway_response": 70,
    "aws_api_gateway_integration": 70,
    "aws_api_gateway_integration_response": 70,
    "aws_api_gateway_method": 70,
    "aws_api_gateway_method_response": 70,
    "aws_api_gateway_method_settings": 70,
    "aws_api_gateway_model": 70,
    "aws_api_gateway_resource": 70,
    "aws_api_gateway_rest_api": 70,
    "aws_api_gateway_stage": 70,
    "aws_api_gateway_usage_plan": 70,
    "aws_api_gateway_usage_plan_key": 70,
    "aws_appautoscaling_policy": 71,
    "aws_appautoscaling_scheduled_action": 71,
    "aws_appautoscaling_target": 71,
    "aws_athena_database": 72,
    "aws_athena_named_query": 72,
    "aws_batch_compute_environment": 73,
    "aws_batch_job_definition": 73,
    "aws_batch_job_queue": 73,
    "aws_cloudformation_stack": 74,
    "aws_cloudfront_distribution": 75,
    "aws_cloudfront_origin_access_identity": 75,
    "aws_cloudtrail": 76,
    "aws_cloudwatch_dashboard": 77,
    "aws_cloudwatch_event_permission": 77,
    "aws_cloudwatch_event_rule": 77,
    "aws_cloudwatch_event_target": 77,
    "aws_cloudwatch_log_destination": 77,
    "aws_cloudwatch_log_destination_policy": 77,
    "aws_cloudwatch_log_group": 77,
    "aws_cloudwatch_log_metric_filter": 77,
    "aws_cloudwatch_log_resource_policy": 77,
    "aws_cloudwatch_log_stream": 77,
    "aws_cloudwatch_log_subscription_filter": 77,
    "aws_cloudwatch_metric_alarm": 77,
    "aws_codebuild_project": 78,
    "aws_codecommit_repository": 79,
    "aws_codecommit_trigger": 79,
    "aws_codedeploy_app": 80,
    "aws_codedeploy_deployment_config": 80,
    "aws_codedeploy_deployment_group": 80,
    "aws_codepipeline": 81,
    "aws_cognito_identity_pool": 82,
    "aws_cognito_identity_pool_roles_attachment": 82,
    "aws_cognito_user_pool": 82,
    "aws_cognito_user_pool_client": 82,
    "aws_cognito_user_pool_domain": 82,
    "aws_config_config_rule": 83,
    "aws_config_configuration_recorder": 83,
    "aws_config_configuration_recorder_status": 83,
    "aws_config_delivery_channel": 83,
    "aws_dms_certificate": 84,
    "aws_dms_endpoint": 84,
    "aws_dms_replication_instance": 84,
    "aws_dms_replication_subnet_group": 84,
    "aws_dms_replication_task": 84,
    "aws_devicefarm_project": 85,
    "aws_directory_service_directory": 86,
    "aws_dx_connection": 87,
    "aws_dx_connection_association": 87,
    "aws_dx_lag": 87,
    "aws_dynamodb_table": 88,
    "aws_alb": 89,
    "aws_alb_listener": 89,
    "aws_alb_listener_rule": 89,
    "aws_alb_target_group": 89,
    "aws_alb_target_group_attachment": 89,
    "aws_ami": 89,
    "aws_ami_copy": 89,
    "aws_ami_from_instance": 89,
    "aws_ami_launch_permission": 89,
    "aws_app_cookie_stickiness_policy": 89,
    "aws_autoscaling_attachment": 89,
    "aws_autoscaling_group": 89,
    "aws_autoscaling_lifecycle_hook": 89,
    "aws_autoscaling_notification": 89,
    "aws_autoscaling_policy": 89,
    "aws_autoscaling_schedule": 89,
    "aws_snapshot_create_volume_permission": 89,
    "aws_ebs_snapshot": 89,
    "aws_ebs_volume": 89,
    "aws_eip": 89,
    "aws_eip_association": 89,
    "aws_elb": 89,
    "aws_elb_attachment": 89,
    "aws_instance": 89,
    "aws_key_pair": 89,
    "aws_launch_configuration": 89,
    "aws_lb_cookie_stickiness_policy": 89,
    "aws_lb_ssl_negotiation_policy": 89,
    "aws_load_balancer_backend_server_policy": 89,
    "aws_load_balancer_listener_policy": 89,
    "aws_load_balancer_policy": 89,
    "aws_placement_group": 89,
    "aws_proxy_protocol_policy": 89,
    "aws_spot_datafeed_subscription": 89,
    "aws_spot_fleet_request": 89,
    "aws_spot_instance_request": 89,
    "aws_volume_attachment": 89,
    "aws_lb": 90,
    "aws_lb_listener": 90,
    "aws_lb_listener_rule": 90,
    "aws_lb_target_group": 90,
    "aws_lb_target_group_attachment": 90,
    "aws_ecr_lifecycle_policy": 91,
    "aws_ecr_repository": 91,
    "aws_ecr_repository_policy": 91,
    "aws_ecs_cluster": 91,
    "aws_ecs_service": 91,
    "aws_ecs_task_definition": 91,
    "aws_efs_file_system": 92,
    "aws_efs_mount_target": 92,
    "aws_elasticache_cluster": 93,
    "aws_elasticache_parameter_group": 93,
    "aws_elasticache_replication_group": 93,
    "aws_elasticache_security_group": 93,
    "aws_elasticache_subnet_group": 93,
    "aws_elastic_beanstalk_application": 94,
    "aws_elastic_beanstalk_application_version": 94,
    "aws_elastic_beanstalk_configuration_template": 94,
    "aws_elastic_beanstalk_environment": 94,
    "aws_emr_cluster": 95,
    "aws_emr_instance_group": 95,
    "aws_emr_security_configuration": 95,
    "aws_elasticsearch_domain": 96,
    "aws_elasticsearch_domain_policy": 96,
    "aws_elastictranscoder_pipeline": 97,
    "aws_elastictranscoder_preset": 97,
    "aws_glacier_vault": 98,
    "aws_glue_catalog_database": 99,
    "aws_guardduty_detector": 100,
    "aws_guardduty_member": 100,
    "aws_iam_access_key": 101,
    "aws_iam_account_alias": 101,
    "aws_iam_account_password_policy": 101,
    "aws_iam_group": 101,
    "aws_iam_group_membership": 101,
    "aws_iam_group_policy": 101,
    "aws_iam_group_policy_attachment": 101,
    "aws_iam_instance_profile": 101,
    "aws_iam_openid_connect_provider": 101,
    "aws_iam_policy": 101,
    "aws_iam_policy_attachment": 101,
    "aws_iam_role": 101,
    "aws_iam_role_policy": 101,
    "aws_iam_role_policy_attachment": 101,
    "aws_iam_saml_provider": 101,
    "aws_iam_server_certificate": 101,
    "aws_iam_user": 101,
    "aws_iam_user_login_profile": 101,
    "aws_iam_user_policy": 101,
    "aws_iam_user_policy_attachment": 101,
    "aws_iam_user_ssh_key": 101,
    "aws_iot_certificate": 102,
    "aws_iot_policy": 102,
    "aws_inspector_assessment_target": 103,
    "aws_inspector_assessment_template": 103,
    "aws_inspector_resource_group": 103,
    "aws_kinesis_stream": 104,
    "aws_kinesis_firehose_delivery_stream": 105,
    "aws_kms_alias": 106,
    "aws_kms_key": 106,
    "aws_lambda_alias": 107,
    "aws_lambda_event_source_mapping": 107,
    "aws_lambda_function": 107,
    "aws_lambda_permission": 107,
    "aws_lightsail_domain": 108,
    "aws_lightsail_instance": 108,
    "aws_lightsail_key_pair": 108,
    "aws_lightsail_static_ip": 108,
    "aws_lightsail_static_ip_attachment": 108,
    "aws_mq_broker": 109,
    "aws_mq_configuration": 109,
    "aws_media_store_container": 110,
    "aws_opsworks_application": 111,
    "aws_opsworks_custom_layer": 111,
    "aws_opsworks_ganglia_layer": 111,
    "aws_opsworks_haproxy_layer": 111,
    "aws_opsworks_instance": 111,
    "aws_opsworks_java_app_layer": 111,
    "aws_opsworks_memcached_layer": 111,
    "aws_opsworks_mysql_layer": 111,
    "aws_opsworks_nodejs_app_layer": 111,
    "aws_opsworks_permission": 111,
    "aws_opsworks_php_app_layer": 111,
    "aws_opsworks_rails_app_layer": 111,
    "aws_opsworks_rds_db_instance": 111,
    "aws_opsworks_stack": 111,
    "aws_opsworks_static_web_layer": 111,
    "aws_opsworks_user_profile": 111,
    "aws_db_event_subscription": 112,
    "aws_db_instance": 112,
    "aws_db_option_group": 112,
    "aws_db_parameter_group": 112,
    "aws_db_security_group": 112,
    "aws_db_snapshot": 112,
    "aws_db_subnet_group": 112,
    "aws_rds_cluster": 112,
    "aws_rds_cluster_instance": 112,
    "aws_rds_cluster_parameter_group": 112,
    "aws_redshift_cluster": 113,
    "aws_redshift_parameter_group": 113,
    "aws_redshift_security_group": 113,
    "aws_redshift_subnet_group": 113,
    "aws_waf_byte_match_set": 114,
    "aws_waf_ipset": 114,
    "aws_waf_rule": 114,
    "aws_waf_rate_based_rule": 114,
    "aws_waf_size_constraint_set": 114,
    "aws_waf_sql_injection_match_set": 114,
    "aws_waf_web_acl": 114,
    "aws_waf_xss_match_set": 114,
    "aws_wafregional_byte_match_set": 115,
    "aws_wafregional_ipset": 115,
    "aws_route53_delegation_set": 116,
    "aws_route53_health_check": 116,
    "aws_route53_query_log": 116,
    "aws_route53_record": 116,
    "aws_route53_zone": 116,
    "aws_route53_zone_association": 116,
    "aws_s3_bucket": 117,
    "aws_s3_bucket_notification": 117,
    "aws_s3_bucket_object": 117,
    "aws_s3_bucket_policy": 117,
    "aws_ses_active_receipt_rule_set": 118,
    "aws_ses_domain_identity": 118,
    "aws_ses_domain_dkim": 118,
    "aws_ses_receipt_filter": 118,
    "aws_ses_receipt_rule": 118,
    "aws_ses_receipt_rule_set": 118,
    "aws_ses_configuration_set": 118,
    "aws_ses_event_destination": 118,
    "aws_ses_template": 118,
    "aws_servicecatalog_portfolio": 119,
    "aws_service_discovery_private_dns_namespace": 120,
    "aws_service_discovery_public_dns_namespace": 120,
    "aws_service_discovery_service": 120,
    "aws_sfn_activity": 121,
    "aws_sfn_state_machine": 121,
    "aws_simpledb_domain": 122,
    "aws_sns_topic": 123,
    "aws_sns_topic_policy": 123,
    "aws_sns_topic_subscription": 123,
    "aws_ssm_activation": 124,
    "aws_ssm_association": 124,
    "aws_ssm_document": 124,
    "aws_ssm_maintenance_window": 124,
    "aws_ssm_maintenance_window_target": 124,
    "aws_ssm_maintenance_window_task": 124,
    "aws_ssm_patch_baseline": 124,
    "aws_ssm_patch_group": 124,
    "aws_ssm_parameter": 124,
    "aws_ssm_resource_data_sync": 124,
    "aws_sqs_queue": 125,
    "aws_sqs_queue_policy": 125,
    "aws_customer_gateway": 126,
    "aws_default_network_acl": 126,
    "aws_default_route_table": 126,
    "aws_default_security_group": 126,
    "aws_default_subnet": 126,
    "aws_default_vpc": 126,
    "aws_default_vpc_dhcp_options": 126,
    "aws_egress_only_internet_gateway": 126,
    "aws_flow_log": 126,
    "aws_internet_gateway": 126,
    "aws_main_route_table_association": 126,
    "aws_nat_gateway": 126,
    "aws_network_acl": 126,
    "aws_network_acl_rule": 126,
    "aws_network_interface": 126,
    "aws_network_interface_attachment": 126,
    "aws_route": 126,
    "aws_route_table": 126,
    "aws_route_table_association": 126,
    "aws_security_group": 126,
    "aws_network_interface_sg_attachment": 126,
    "aws_security_group_rule": 126,
    "aws_subnet": 126,
    "aws_vpc": 126,
    "aws_vpc_dhcp_options": 126,
    "aws_vpc_dhcp_options_association": 126,
    "aws_vpc_endpoint": 126,
    "aws_vpc_endpoint_route_table_association": 126,
    "aws_vpc_peering_connection": 126,
    "aws_vpc_peering_connection_accepter": 126,
    "aws_vpn_connection": 126,
    "aws_vpn_connection_route": 126,
    "aws_vpn_gateway": 126,
    "aws_vpn_gateway_attachment": 126,
    "aws_vpn_gateway_route_propagation": 126,
    "datadog_downtime": 127,
    "datadog_monitor": 127,
    "datadog_timeboard": 127,
    "datadog_user": 127,
    "vcd_dnat": 128,
    "vcd_firewall_rules": 128,
    "vcd_network": 128,
    "vcd_snat": 128,
    "vcd_edgegateway_vpn": 128,
    "vcd_vapp": 128,
    "vcd_vapp_vm": 128,
    "powerdns_record": 129,
    "ultradns_dirpool": 130,
    "ultradns_probe_http": 130,
    "ultradns_probe_ping": 130,
    "ultradns_record": 130,
    "ultradns_tcpool": 130,
    "alicloud_disk": 131,
    "alicloud_disk_attachment": 131,
    "alicloud_instance": 131,
    "alicloud_eip": 131,
    "alicloud_eip_association": 131,
    "alicloud_slb": 132,
    "alicloud_slb_attachment": 132,
    "alicloud_vpc": 133,
    "alicloud_vswitch": 133,
    "alicloud_route_entry": 133,
    "alicloud_security_group": 133,
    "alicloud_security_group_rule": 133,
    "alicloud_nat_gateway": 133,
    "alicloud_rds": 134,
    "alicloud_ess_scaling_group": 135,
    "alicloud_ess_scaling_configuration": 135,
    "alicloud_ess_scaling_rule": 135,
    "alicloud_ess_schedule": 135,
    "icinga2_checkcommand": 136,
    "icinga2_host": 136,
    "icinga2_hostgroup": 136,
    "icinga2_service": 136,
    "statuscake_test": 137,
    "digitalocean_certificate": 138,
    "digitalocean_domain": 138,
    "digitalocean_droplet": 138,
    "digitalocean_firewall": 138,
    "digitalocean_floating_ip": 138,
    "digitalocean_loadbalancer": 138,
    "digitalocean_record": 138,
    "digitalocean_ssh_key": 138,
    "digitalocean_tag": 138,
    "digitalocean_volume": 138,
    "nomad_job": 139,
    "dnsimple_record": 140,
    "logentries_log": 141,
    "logentries_logset": 141,
    "rabbitmq_binding": 142,
    "rabbitmq_exchange": 142,
    "rabbitmq_permissions": 142,
    "rabbitmq_policy": 142,
    "rabbitmq_queue": 142,
    "rabbitmq_user": 142,
    "rabbitmq_vhost": 142,
    "random_id": 143,
    "random_pet": 143,
    "random_shuffle": 143,
    "random_string": 143,
    "random_integer": 143,
    "opc_compute_acl": 144,
    "opc_compute_image_list": 144,
    "opc_compute_image_list_entry": 144,
    "opc_compute_instance": 144,
    "opc_compute_ip_address_association": 144,
    "opc_compute_ip_address_prefix_set": 144,
    "opc_compute_ip_address_reservation": 144,
    "opc_compute_ip_association": 144,
    "opc_compute_ip_network": 144,
    "opc_compute_ip_network_exchange": 144,
    "opc_compute_ip_reservation": 144,
    "opc_compute_machine_image": 144,
    "opc_compute_orchestrated_instance": 144,
    "opc_compute_route": 144,
    "opc_compute_sec_rule": 144,
    "opc_compute_security_application": 144,
    "opc_compute_security_association": 144,
    "opc_compute_security_ip_list": 144,
    "opc_compute_security_list": 144,
    "opc_compute_security_protocol": 144,
    "opc_compute_security_rule": 144,
    "opc_compute_ssh_key": 144,
    "opc_compute_storage_volume_attachment": 144,
    "opc_compute_storage_volume": 144,
    "opc_compute_storage_volume_snapshot": 144,
    "opc_compute_vnic_set": 144,
    "opc_storage_container": 145,
    "opc_storage_object": 145,
    "opentelekomcloud_blockstorage_volume_v2": 146,
    "opentelekomcloud_compute_floatingip_v2": 147,
    "opentelekomcloud_compute_floatingip_associate_v2": 147,
    "opentelekomcloud_compute_instance_v2": 147,
    "opentelekomcloud_compute_keypair_v2": 147,
    "opentelekomcloud_compute_secgroup_v2": 147,
    "opentelekomcloud_compute_servergroup_v2": 147,
    "opentelekomcloud_compute_volume_attach_v2": 147,
    "opentelekomcloud_dns_recordset_v2": 148,
    "opentelekomcloud_dns_zone_v2": 148,
    "opentelekomcloud_images_image_v2": 149,
    "opentelekomcloud_networking_floatingip_v2": 150,
    "opentelekomcloud_networking_network_v2": 150,
    "opentelekomcloud_networking_port_v2": 150,
    "opentelekomcloud_networking_router_interface_v2": 150,
    "opentelekomcloud_networking_router_route_v2": 150,
    "opentelekomcloud_networking_router_v2": 150,
    "opentelekomcloud_networking_subnet_v2": 150,
    "opentelekomcloud_networking_secgroup_v2": 150,
    "opentelekomcloud_networking_secgroup_rule_v2": 150,
    "opentelekomcloud_lb_loadbalancer_v2": 151,
    "opentelekomcloud_lb_listener_v2": 151,
    "opentelekomcloud_lb_pool_v2": 151,
    "opentelekomcloud_lb_member_v2": 151,
    "opentelekomcloud_lb_monitor_v2": 151,
    "opentelekomcloud_fw_firewall_group_v2": 152,
    "opentelekomcloud_fw_policy_v2": 152,
    "opentelekomcloud_fw_rule_v2": 152,
    "cloudstack_affinity_group": 153,
    "cloudstack_disk": 153,
    "cloudstack_egress_firewall": 153,
    "cloudstack_firewall": 153,
    "cloudstack_instance": 153,
    "cloudstack_ipaddress": 153,
    "cloudstack_loadbalancer_rule": 153,
    "cloudstack_network": 153,
    "cloudstack_network_acl": 153,
    "cloudstack_network_acl_rule": 153,
    "cloudstack_nic": 153,
    "cloudstack_port_forward": 153,
    "cloudstack_private_gateway": 153,
    "cloudstack_secondary_ipaddress": 153,
    "cloudstack_security_group": 153,
    "cloudstack_security_group_rule": 153,
    "cloudstack_ssh_keypair": 153,
    "cloudstack_static_nat": 153,
    "cloudstack_static_route": 153,
    "cloudstack_template": 153,
    "cloudstack_vpc": 153,
    "cloudstack_vpn_gateway": 153,
    "cloudstack_vpn_customer_gateway": 153,
    "cloudstack_vpn_connection": 153,
    "docker_container": 154,
    "docker_image": 154,
    "docker_network": 154,
    "docker_volume": 154,
    "grafana_alert_notification": 155,
    "grafana_dashboard": 155,
    "grafana_data_source": 155,
    "gitlab_deploy_key": 156,
    "gitlab_group": 156,
    "gitlab_label": 156,
    "gitlab_project_hook": 156,
    "gitlab_project": 156,
    "gitlab_user": 156,
    "ns1_zone": 157,
    "ns1_record": 157,
    "ns1_monitoringjob": 157,
    "ns1_notifylist": 157,
    "ns1_datasource": 157,
    "ns1_datafeed": 157,
    "ns1_apikey": 157,
    "ns1_team": 157,
    "ns1_user": 157,
    "ovh_vrack_publiccloud_attachment": 158,
    "ovh_publiccloud_private_network": 159,
    "ovh_publiccloud_private_network_subnet": 159,
    "ovh_publiccloud_user": 159,
    "pagerduty_addon": 160,
    "pagerduty_escalation_policy": 160,
    "pagerduty_maintenance_window": 160,
    "pagerduty_schedule": 160,
    "pagerduty_service": 160,
    "pagerduty_service_integration": 160,
    "pagerduty_team": 160,
    "pagerduty_team_membership": 160,
    "pagerduty_user": 160,
    "pagerduty_user_contact_method": 160,
    "rundeck_project": 161,
    "rundeck_private_key": 161,
    "rundeck_public_key": 161,
    "rundeck_job": 161,
    "triton_fabric": 162,
    "triton_firewall_rule": 162,
    "triton_key": 162,
    "triton_machine": 162,
    "triton_snapshot": 162,
    "triton_vlan": 162,
    "influxdb_database": 163,
    "influxdb_user": 163,
    "influxdb_continuous_query": 163,
    "logicmonitor_collectorgroup": 164,
    "logicmonitor_device": 164,
    "logicmonitor_devicegroup": 164,
    "file": 165,
    "openstack_blockstorage_volume_v1": 166,
    "openstack_blockstorage_volume_v2": 166,
    "openstack_blockstorage_volume_attach_v2": 166,
    "openstack_compute_flavor_v2": 167,
    "openstack_compute_floatingip_v2": 167,
    "openstack_compute_floatingip_associate_v2": 167,
    "openstack_compute_instance_v2": 167,
    "openstack_compute_keypair_v2": 167,
    "openstack_compute_secgroup_v2": 167,
    "openstack_compute_servergroup_v2": 167,
    "openstack_compute_volume_attach_v2": 167,
    "openstack_db_instance_v1": 168,
    "openstack_db_database_v1": 168,
    "openstack_db_user_v1": 168,
    "openstack_db_configuration_v1": 168,
    "openstack_dns_recordset_v2": 169,
    "openstack_dns_zone_v2": 169,
    "openstack_identity_project_v3": 170,
    "openstack_identity_user_v3": 170,
    "openstack_images_image_v2": 171,
    "openstack_networking_floatingip_v2": 172,
    "openstack_networking_network_v2": 172,
    "openstack_networking_port_v2": 172,
    "openstack_networking_router_interface_v2": 172,
    "openstack_networking_router_route_v2": 172,
    "openstack_networking_router_v2": 172,
    "openstack_networking_subnet_v2": 172,
    "openstack_networking_secgroup_v2": 172,
    "openstack_networking_secgroup_rule_v2": 172,
    "openstack_lb_member_v1": 173,
    "openstack_lb_monitor_v1": 173,
    "openstack_lb_pool_v1": 173,
    "openstack_lb_vip_v1": 173,
    "openstack_lb_loadbalancer_v2": 173,
    "openstack_lb_listener_v2": 173,
    "openstack_lb_pool_v2": 173,
    "openstack_lb_member_v2": 173,
    "openstack_lb_monitor_v2": 173,
    "openstack_fw_firewall_v1": 174,
    "openstack_fw_policy_v1": 174,
    "openstack_fw_rule_v1": 174,
    "openstack_objectstorage_container_v1": 175,
    "openstack_objectstorage_object_v1": 175,
    "tls_private_key": 176,
    "tls_self_signed_cert": 176,
    "tls_locally_signed_cert": 176,
    "tls_cert_request": 176,
    "dns_a_record_set": 177,
    "dns_aaaa_record_set": 177,
    "dns_cname_record": 177,
    "dns_ptr_record": 177,
    "dyn_record": 178,
    "": 10000,
    "provider": 10000,
    "meta": 10000,
    "var": 10001,
    "output": 10002
}
